var searchData=
[
  ['nats_5fcheckcompatibility_0',['nats_CheckCompatibility',['../group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e',1,'nats.h']]],
  ['nats_5fclose_1',['nats_Close',['../group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e',1,'nats.h']]],
  ['nats_5fcloseandwait_2',['nats_CloseAndWait',['../group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903',1,'nats.h']]],
  ['nats_5fgetlasterror_3',['nats_GetLastError',['../group__library_group.html#gadecfd49a58b581dbba40da77b195fd85',1,'nats.h']]],
  ['nats_5fgetlasterrorstack_4',['nats_GetLastErrorStack',['../group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e',1,'nats.h']]],
  ['nats_5fgetversion_5',['nats_GetVersion',['../group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8',1,'nats.h']]],
  ['nats_5fgetversionnumber_6',['nats_GetVersionNumber',['../group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8',1,'nats.h']]],
  ['nats_5fnow_7',['nats_Now',['../group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e',1,'nats.h']]],
  ['nats_5fnowinnanoseconds_8',['nats_NowInNanoSeconds',['../group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223',1,'nats.h']]],
  ['nats_5fopen_9',['nats_Open',['../group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d',1,'nats.h']]],
  ['nats_5fprintlasterrorstack_10',['nats_PrintLastErrorStack',['../group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4',1,'nats.h']]],
  ['nats_5freleasethreadmemory_11',['nats_ReleaseThreadMemory',['../group__library_group.html#gafe171baefa00a85b77205116e9f3e48a',1,'nats.h']]],
  ['nats_5fsetmessagedeliverypoolsize_12',['nats_SetMessageDeliveryPoolSize',['../group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d',1,'nats.h']]],
  ['nats_5fsign_13',['nats_Sign',['../group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba',1,'nats.h']]],
  ['nats_5fsleep_14',['nats_Sleep',['../group__library_group.html#gad5040264cd4b1404956babf3c03a4f09',1,'nats.h']]],
  ['natsconnection_5fbuffered_15',['natsConnection_Buffered',['../group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5',1,'nats.h']]],
  ['natsconnection_5fclose_16',['natsConnection_Close',['../group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed',1,'nats.h']]],
  ['natsconnection_5fconnect_17',['natsConnection_Connect',['../group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce',1,'nats.h']]],
  ['natsconnection_5fconnectto_18',['natsConnection_ConnectTo',['../group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4',1,'nats.h']]],
  ['natsconnection_5fdestroy_19',['natsConnection_Destroy',['../group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495',1,'nats.h']]],
  ['natsconnection_5fdrain_20',['natsConnection_Drain',['../group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b',1,'nats.h']]],
  ['natsconnection_5fdraintimeout_21',['natsConnection_DrainTimeout',['../group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4',1,'nats.h']]],
  ['natsconnection_5fflush_22',['natsConnection_Flush',['../group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f',1,'nats.h']]],
  ['natsconnection_5fflushtimeout_23',['natsConnection_FlushTimeout',['../group__conn_mgt_group.html#ga85915ef0c8b87993be1b076099d6a7c1',1,'nats.h']]],
  ['natsconnection_5fgetclientid_24',['natsConnection_GetClientID',['../group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba',1,'nats.h']]],
  ['natsconnection_5fgetclientip_25',['natsConnection_GetClientIP',['../group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d',1,'nats.h']]],
  ['natsconnection_5fgetconnectedserverid_26',['natsConnection_GetConnectedServerId',['../group__conn_mgt_group.html#ga48cee9ea1cdc9fc2770de2f9f0fd1ccf',1,'nats.h']]],
  ['natsconnection_5fgetconnectedurl_27',['natsConnection_GetConnectedUrl',['../group__conn_mgt_group.html#gaf623280407c43ade02285005f0642e6d',1,'nats.h']]],
  ['natsconnection_5fgetdiscoveredservers_28',['natsConnection_GetDiscoveredServers',['../group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708',1,'nats.h']]],
  ['natsconnection_5fgetlasterror_29',['natsConnection_GetLastError',['../group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63',1,'nats.h']]],
  ['natsconnection_5fgetlocalipandport_30',['natsConnection_GetLocalIPAndPort',['../group__conn_mgt_group.html#ga761095a42374b4dafa178df7d7652dd5',1,'nats.h']]],
  ['natsconnection_5fgetmaxpayload_31',['natsConnection_GetMaxPayload',['../group__conn_mgt_group.html#ga68e7149f7ff1cc4989b3f795fa7e76d9',1,'nats.h']]],
  ['natsconnection_5fgetrtt_32',['natsConnection_GetRTT',['../group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435',1,'nats.h']]],
  ['natsconnection_5fgetservers_33',['natsConnection_GetServers',['../group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b',1,'nats.h']]],
  ['natsconnection_5fgetstats_34',['natsConnection_GetStats',['../group__conn_mgt_group.html#ga68821a8ae1176096b5afef7fdc7947ec',1,'nats.h']]],
  ['natsconnection_5fhasheadersupport_35',['natsConnection_HasHeaderSupport',['../group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a',1,'nats.h']]],
  ['natsconnection_5fisclosed_36',['natsConnection_IsClosed',['../group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f',1,'nats.h']]],
  ['natsconnection_5fisdraining_37',['natsConnection_IsDraining',['../group__conn_mgt_group.html#ga15a0f8aa9a6f621535d01593a4c8edd5',1,'nats.h']]],
  ['natsconnection_5fisreconnecting_38',['natsConnection_IsReconnecting',['../group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688',1,'nats.h']]],
  ['natsconnection_5fjetstream_39',['natsConnection_JetStream',['../group__js_group.html#ga8ed08b0fe1074b1e490291f0af2cb03f',1,'nats.h']]],
  ['natsconnection_5fprocessreadevent_40',['natsConnection_ProcessReadEvent',['../group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8',1,'nats.h']]],
  ['natsconnection_5fprocesswriteevent_41',['natsConnection_ProcessWriteEvent',['../group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47',1,'nats.h']]],
  ['natsconnection_5fpublish_42',['natsConnection_Publish',['../group__conn_pub_group.html#gac0b9f7759ecc39b8d77807b94254f9b4',1,'nats.h']]],
  ['natsconnection_5fpublishmsg_43',['natsConnection_PublishMsg',['../group__conn_pub_group.html#ga74511acd87385931112c45c48c2a14ba',1,'nats.h']]],
  ['natsconnection_5fpublishrequest_44',['natsConnection_PublishRequest',['../group__conn_pub_group.html#gaaaa3d75ffec2dcdc6bf905cdb1eee59e',1,'nats.h']]],
  ['natsconnection_5fpublishrequeststring_45',['natsConnection_PublishRequestString',['../group__conn_pub_group.html#gaafca9a8294e81a5a9979e762931e56c5',1,'nats.h']]],
  ['natsconnection_5fpublishstring_46',['natsConnection_PublishString',['../group__conn_pub_group.html#gad09a717c20de4cf0e2a21dcfd9ce6c64',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribe_47',['natsConnection_QueueSubscribe',['../group__conn_sub_group.html#ga3c9fee2775130786ef62f1cbeb191a48',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribesync_48',['natsConnection_QueueSubscribeSync',['../group__conn_sub_group.html#ga68630ea7c4bbdc7f8cd62058b41fb476',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribetimeout_49',['natsConnection_QueueSubscribeTimeout',['../group__conn_sub_group.html#ga96fa115fd5b2ef7658884da80714b91c',1,'nats.h']]],
  ['natsconnection_5frequest_50',['natsConnection_Request',['../group__conn_pub_group.html#gaf4b4a022f9c21fc269b87c000330c5a7',1,'nats.h']]],
  ['natsconnection_5frequestmsg_51',['natsConnection_RequestMsg',['../group__conn_pub_group.html#ga052de4b75b3b69ccd8d20eb4861b801d',1,'nats.h']]],
  ['natsconnection_5frequeststring_52',['natsConnection_RequestString',['../group__conn_pub_group.html#ga4bb5105df6a3efd2088e6be0fdf6b31f',1,'nats.h']]],
  ['natsconnection_5fsign_53',['natsConnection_Sign',['../group__conn_mgt_group.html#ga6960cfdbaac3b8759784f352d4c264f8',1,'nats.h']]],
  ['natsconnection_5fstatus_54',['natsConnection_Status',['../group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98',1,'nats.h']]],
  ['natsconnection_5fsubscribe_55',['natsConnection_Subscribe',['../group__conn_sub_group.html#gaefab965b5645798d47f9244f2b3fe3fb',1,'nats.h']]],
  ['natsconnection_5fsubscribesync_56',['natsConnection_SubscribeSync',['../group__conn_sub_group.html#ga17574d5165f7e285462e3d3b2709edf4',1,'nats.h']]],
  ['natsconnection_5fsubscribetimeout_57',['natsConnection_SubscribeTimeout',['../group__conn_sub_group.html#gacb2c83b58b7909715424cbc327fdd404',1,'nats.h']]],
  ['natsinbox_5fcreate_58',['natsInbox_Create',['../group__inbox_group.html#gaa1ec779a0b7ead54b78da05533848b6d',1,'nats.h']]],
  ['natsinbox_5fdestroy_59',['natsInbox_Destroy',['../group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe',1,'nats.h']]],
  ['natslibevent_5fattach_60',['natsLibevent_Attach',['../group__libevent_functions.html#ga30c00f21a5251ee9fde09c1f2b429cd2',1,'libevent.h']]],
  ['natslibevent_5fdetach_61',['natsLibevent_Detach',['../group__libevent_functions.html#gaac76f5937329a8650f69c6bd8af36cd5',1,'libevent.h']]],
  ['natslibevent_5finit_62',['natsLibevent_Init',['../group__libevent_functions.html#ga195d269473332931fd0fede0bac3309e',1,'libevent.h']]],
  ['natslibevent_5fread_63',['natsLibevent_Read',['../group__libevent_functions.html#ga8a14ce23b4f6ba3bf63369961f9a5552',1,'libevent.h']]],
  ['natslibevent_5fwrite_64',['natsLibevent_Write',['../group__libevent_functions.html#ga7ac99f326a59e5663ff66f5023c87091',1,'libevent.h']]],
  ['natslibuv_5fattach_65',['natsLibuv_Attach',['../group__libuv_functions.html#ga86ac71cffe752effd7397740d80c3c42',1,'libuv.h']]],
  ['natslibuv_5fdetach_66',['natsLibuv_Detach',['../group__libuv_functions.html#ga8df663525fb59b882a0f3bd563083dc7',1,'libuv.h']]],
  ['natslibuv_5finit_67',['natsLibuv_Init',['../group__libuv_functions.html#ga5d4b677cbe1cd132c37bc56dbfc6949e',1,'libuv.h']]],
  ['natslibuv_5fread_68',['natsLibuv_Read',['../group__libuv_functions.html#ga85c722b2d2699a954362b20528f0aaac',1,'libuv.h']]],
  ['natslibuv_5fsetthreadlocalloop_69',['natsLibuv_SetThreadLocalLoop',['../group__libuv_functions.html#ga1baf4a20b138dcf00807a8b830f4e02d',1,'libuv.h']]],
  ['natslibuv_5fwrite_70',['natsLibuv_Write',['../group__libuv_functions.html#gafaa633c9067f485f330b72644277b07d',1,'libuv.h']]],
  ['natsmsg_5fack_71',['natsMsg_Ack',['../group__js_msg.html#gae454fb7e7097a3cd3362cb49ef8a3c84',1,'nats.h']]],
  ['natsmsg_5facksync_72',['natsMsg_AckSync',['../group__js_msg.html#gafb899ebf8e89b3a858fe20f7853635a7',1,'nats.h']]],
  ['natsmsg_5fcreate_73',['natsMsg_Create',['../group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21',1,'nats.h']]],
  ['natsmsg_5fdestroy_74',['natsMsg_Destroy',['../group__msg_group.html#ga9e9590018284939f43f60964283f33ae',1,'nats.h']]],
  ['natsmsg_5fgetdata_75',['natsMsg_GetData',['../group__msg_group.html#ga523364451fd92534e754054266196e59',1,'nats.h']]],
  ['natsmsg_5fgetdatalength_76',['natsMsg_GetDataLength',['../group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de',1,'nats.h']]],
  ['natsmsg_5fgetmetadata_77',['natsMsg_GetMetaData',['../group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328',1,'nats.h']]],
  ['natsmsg_5fgetreply_78',['natsMsg_GetReply',['../group__msg_group.html#ga880535362c91b3e405792aa66ff945b6',1,'nats.h']]],
  ['natsmsg_5fgetsequence_79',['natsMsg_GetSequence',['../group__js_msg.html#ga819be2990ec20b964aa574b5331d7f2e',1,'nats.h']]],
  ['natsmsg_5fgetsubject_80',['natsMsg_GetSubject',['../group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a',1,'nats.h']]],
  ['natsmsg_5fgettime_81',['natsMsg_GetTime',['../group__js_msg.html#gab4850497c5481f5ec6eb1fcdb43646f5',1,'nats.h']]],
  ['natsmsg_5finprogress_82',['natsMsg_InProgress',['../group__js_msg.html#gae1e0beb19cd76e2f69e6415c41c9bb39',1,'nats.h']]],
  ['natsmsg_5fisnoresponders_83',['natsMsg_IsNoResponders',['../group__msg_group.html#ga43aa4a8e4b93725b4876ee2677e19c7b',1,'nats.h']]],
  ['natsmsg_5fnak_84',['natsMsg_Nak',['../group__js_msg.html#gac271b874154301da9759f9ac05768b47',1,'nats.h']]],
  ['natsmsg_5fnakwithdelay_85',['natsMsg_NakWithDelay',['../group__js_msg.html#gac0697389fa60a3c4725e53cd23ada7bd',1,'nats.h']]],
  ['natsmsg_5fterm_86',['natsMsg_Term',['../group__js_msg.html#gae84d21e4388255e9d990e53c9f67e7c4',1,'nats.h']]],
  ['natsmsgheader_5fadd_87',['natsMsgHeader_Add',['../group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b',1,'nats.h']]],
  ['natsmsgheader_5fdelete_88',['natsMsgHeader_Delete',['../group__msg_group.html#gac78ca02dc93d05cae837ced6386408f1',1,'nats.h']]],
  ['natsmsgheader_5fget_89',['natsMsgHeader_Get',['../group__msg_group.html#gab3349f0b0ce721b340d5c0753c90ee18',1,'nats.h']]],
  ['natsmsgheader_5fkeys_90',['natsMsgHeader_Keys',['../group__msg_group.html#ga6ee8a007111ada293dd24ff0bab02491',1,'nats.h']]],
  ['natsmsgheader_5fset_91',['natsMsgHeader_Set',['../group__msg_group.html#gaf30b47d4217c9335919f05536e379af8',1,'nats.h']]],
  ['natsmsgheader_5fvalues_92',['natsMsgHeader_Values',['../group__msg_group.html#gae1ce9c9d82d151a3ea9dc03da048f66f',1,'nats.h']]],
  ['natsmsglist_5fdestroy_93',['natsMsgList_Destroy',['../group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2',1,'nats.h']]],
  ['natsoptions_5fcreate_94',['natsOptions_Create',['../group__opts_group.html#ga61d4a0cf2fbf7d13cc910e5a00c575be',1,'nats.h']]],
  ['natsoptions_5fdestroy_95',['natsOptions_Destroy',['../group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9',1,'nats.h']]],
  ['natsoptions_5fdisablenoresponders_96',['natsOptions_DisableNoResponders',['../group__opts_group.html#ga192465163abb87ad48a843b45cdf9984',1,'nats.h']]],
  ['natsoptions_5fipresolutionorder_97',['natsOptions_IPResolutionOrder',['../group__opts_group.html#ga7ca713c7532eff4d41a492e95b8822cf',1,'nats.h']]],
  ['natsoptions_5floadcatrustedcertificates_98',['natsOptions_LoadCATrustedCertificates',['../group__opts_group.html#ga2cd6563694a439b3949a31fd81103099',1,'nats.h']]],
  ['natsoptions_5floadcertificateschain_99',['natsOptions_LoadCertificatesChain',['../group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b',1,'nats.h']]],
  ['natsoptions_5fsetallowreconnect_100',['natsOptions_SetAllowReconnect',['../group__opts_group.html#ga3d1d3cb2f2a0e23d27dd60e96d1cc91b',1,'nats.h']]],
  ['natsoptions_5fsetcatrustedcertificates_101',['natsOptions_SetCATrustedCertificates',['../group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8',1,'nats.h']]],
  ['natsoptions_5fsetcertificateschain_102',['natsOptions_SetCertificatesChain',['../group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c',1,'nats.h']]],
  ['natsoptions_5fsetciphers_103',['natsOptions_SetCiphers',['../group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c',1,'nats.h']]],
  ['natsoptions_5fsetciphersuites_104',['natsOptions_SetCipherSuites',['../group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0',1,'nats.h']]],
  ['natsoptions_5fsetclosedcb_105',['natsOptions_SetClosedCB',['../group__opts_group.html#ga44410242e73134e5bb51ef27904a9253',1,'nats.h']]],
  ['natsoptions_5fsetcustominboxprefix_106',['natsOptions_SetCustomInboxPrefix',['../group__opts_group.html#gac5173473a731a4a36d15346fedddf91f',1,'nats.h']]],
  ['natsoptions_5fsetcustomreconnectdelay_107',['natsOptions_SetCustomReconnectDelay',['../group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d',1,'nats.h']]],
  ['natsoptions_5fsetdisconnectedcb_108',['natsOptions_SetDisconnectedCB',['../group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039',1,'nats.h']]],
  ['natsoptions_5fsetdiscoveredserverscb_109',['natsOptions_SetDiscoveredServersCB',['../group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65',1,'nats.h']]],
  ['natsoptions_5fseterrorhandler_110',['natsOptions_SetErrorHandler',['../group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd',1,'nats.h']]],
  ['natsoptions_5fseteventloop_111',['natsOptions_SetEventLoop',['../group__opts_group.html#gab09491bad908dedcb323c780280733ff',1,'nats.h']]],
  ['natsoptions_5fsetexpectedhostname_112',['natsOptions_SetExpectedHostname',['../group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851',1,'nats.h']]],
  ['natsoptions_5fsetfailrequestsondisconnect_113',['natsOptions_SetFailRequestsOnDisconnect',['../group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79',1,'nats.h']]],
  ['natsoptions_5fsetignorediscoveredservers_114',['natsOptions_SetIgnoreDiscoveredServers',['../group__opts_group.html#ga7e4172084520708b8c9f28e73174461c',1,'nats.h']]],
  ['natsoptions_5fsetiobufsize_115',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
  ['natsoptions_5fsetlameduckmodecb_116',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
  ['natsoptions_5fsetmaxpendingmsgs_117',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
  ['natsoptions_5fsetmaxpingsout_118',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
  ['natsoptions_5fsetmaxreconnect_119',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
  ['natsoptions_5fsetname_120',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
  ['natsoptions_5fsetnkey_121',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
  ['natsoptions_5fsetnkeyfromseed_122',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
  ['natsoptions_5fsetnoecho_123',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
  ['natsoptions_5fsetnorandomize_124',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
  ['natsoptions_5fsetpedantic_125',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
  ['natsoptions_5fsetpinginterval_126',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
  ['natsoptions_5fsetreconnectbufsize_127',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
  ['natsoptions_5fsetreconnectedcb_128',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
  ['natsoptions_5fsetreconnectjitter_129',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
  ['natsoptions_5fsetreconnectwait_130',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
  ['natsoptions_5fsetretryonfailedconnect_131',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
  ['natsoptions_5fsetsecure_132',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
  ['natsoptions_5fsetsendasap_133',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
  ['natsoptions_5fsetservers_134',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
  ['natsoptions_5fsettimeout_135',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
  ['natsoptions_5fsettoken_136',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
  ['natsoptions_5fsettokenhandler_137',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
  ['natsoptions_5fseturl_138',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
  ['natsoptions_5fsetusercredentialscallbacks_139',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
  ['natsoptions_5fsetusercredentialsfromfiles_140',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
  ['natsoptions_5fsetuserinfo_141',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
  ['natsoptions_5fsetverbose_142',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
  ['natsoptions_5fsetwritedeadline_143',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
  ['natsoptions_5fskipserververification_144',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
  ['natsoptions_5fuseglobalmessagedelivery_145',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
  ['natsoptions_5fuseoldrequeststyle_146',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
  ['natsstatistics_5fcreate_147',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
  ['natsstatistics_5fdestroy_148',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
  ['natsstatistics_5fgetcounts_149',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
  ['natsstatus_5fgettext_150',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
  ['natssubscription_5fautounsubscribe_151',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
  ['natssubscription_5fclearmaxpending_152',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
  ['natssubscription_5fdestroy_153',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
  ['natssubscription_5fdrain_154',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
  ['natssubscription_5fdraincompletionstatus_155',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
  ['natssubscription_5fdraintimeout_156',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
  ['natssubscription_5ffetch_157',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
  ['natssubscription_5ffetchrequest_158',['natsSubscription_FetchRequest',['../group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed',1,'nats.h']]],
  ['natssubscription_5fgetconsumerinfo_159',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
  ['natssubscription_5fgetdelivered_160',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
  ['natssubscription_5fgetdropped_161',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
  ['natssubscription_5fgetid_162',['natsSubscription_GetID',['../group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20',1,'nats.h']]],
  ['natssubscription_5fgetmaxpending_163',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
  ['natssubscription_5fgetpending_164',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
  ['natssubscription_5fgetpendinglimits_165',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
  ['natssubscription_5fgetsequencemismatch_166',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
  ['natssubscription_5fgetstats_167',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
  ['natssubscription_5fgetsubject_168',['natsSubscription_GetSubject',['../group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432',1,'nats.h']]],
  ['natssubscription_5fisvalid_169',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
  ['natssubscription_5fnextmsg_170',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
  ['natssubscription_5fnodeliverydelay_171',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
  ['natssubscription_5fqueuedmsgs_172',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
  ['natssubscription_5fsetoncompletecb_173',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
  ['natssubscription_5fsetpendinglimits_174',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
  ['natssubscription_5funsubscribe_175',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
  ['natssubscription_5fwaitfordraincompletion_176',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]]
];
